summaryrefslogtreecommitdiffstats
path: root/vespaclient/src/perl/lib/Yahoo/Vespa/ClusterController.pm
diff options
context:
space:
mode:
Diffstat (limited to 'vespaclient/src/perl/lib/Yahoo/Vespa/ClusterController.pm')
-rw-r--r--vespaclient/src/perl/lib/Yahoo/Vespa/ClusterController.pm7
1 files changed, 5 insertions, 2 deletions
diff --git a/vespaclient/src/perl/lib/Yahoo/Vespa/ClusterController.pm b/vespaclient/src/perl/lib/Yahoo/Vespa/ClusterController.pm
index 229253b659e..cac91885fb9 100644
--- a/vespaclient/src/perl/lib/Yahoo/Vespa/ClusterController.pm
+++ b/vespaclient/src/perl/lib/Yahoo/Vespa/ClusterController.pm
@@ -80,8 +80,8 @@ sub detectClusterController { # ()
enableAutomaticLineBreaks($oldVal);
}
}
-sub setNodeUserState { # (ClusterName, NodeType, Index, State, Reason)
- my ($cluster, $service, $index, $state, $reason) = @_;
+sub setNodeUserState { # (ClusterName, NodeType, Index, State, Reason, NoWait)
+ my ($cluster, $service, $index, $state, $reason, $no_wait) = @_;
my @params = ();
my @headers = (
'Content-Type' => 'application/json'
@@ -100,6 +100,9 @@ sub setNodeUserState { # (ClusterName, NodeType, Index, State, Reason)
}
}
};
+ if ($no_wait) {
+ $request->{'response-wait'} = 'no-wait';
+ }
my $content = Json::encode($request);
my $path = &getPathToNode($cluster, $service, $index);